#
# spec file for package convmv
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           convmv
License:        GPL-2.0+
Group:          Productivity/File utilities
AutoReqProv:    on
Version:        1.15
Release:        17.1
Url:            http://j3e.de/linux/convmv/
Source:         http://j3e.de/linux/convmv/%{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Summary:        Converts File Names from One Encoding to Another

%description
convmv is meant to help convert a directory tree and the contained
files or a whole file system into a different encoding. It just
converts the file names, not the content of the files. A special
feature of convmv is that it also takes care of symlinks and converts
the symlink target pointer in case the symlink target is converted.

All this comes in very handy when converting from old 8-bit locales to
UTF-8 locales. It is also possible to convert directories to UTF-8 that
are already partly UTF-8 encoded. convmv is able to detect if certain
files are UTF-8 encoded and skips them by default. To turn this
behavior off, use the --nosmart switch.

An interoperability issue that comes with UTF-8 locales is this: Linux
and (most?) other Unix-like operating systems use the normalization
form C (NFC) for UTF-8 encoding by default but do not enforce this.
Darwin, the base of Macintosh OSX, enforces normalization form D (NFD),
where a few characters are encoded in a different way. convmv is able
to convert files to NFC or NFD, which aids in interoperability with
such systems.



Authors:
--------
    Bjoern Jacke <bjoern@j3e.de>

%prep
%setup -q
%{__tar} xf testsuite.tar

%build
make PREFIX=/usr

%install
mkdir -p $RPM_BUILD_ROOT%{_bindir} $RPM_BUILD_ROOT%{_mandir}/man1
make DESTDIR=$RPM_BUILD_ROOT PREFIX=/usr install

%check 
make test

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-, root, root)
%doc GPL2 Changes CREDITS TODO VERSION
%{_bindir}/*
%{_mandir}/man1/*

%changelog
* Tue Aug 23 2011 tiwai@suse.de
- updated to version 1.15:
  add --dump-options; fix a bug in case-insensitive filesystems;
  see Changes file for details
* Mon Jul 27 2009 tiwai@suse.de
- updated to version 1.14:
  see Changes file for details
* Thu Jan 31 2008 crrodriguez@suse.de
- update to version 1.12 and fix build
- now work with Perl 5.10 using an eval block
- GPL v2 and v3 now
* Tue Jul 11 2006 mfabian@suse.de
- update to 1.10:
  + now use from_to instead of utf8::decode (which is experimental
    and might vanish in the future) to check for valid UTF-8
  + updates and cleanups of testsuite and include "0" filename
  + fix "0" filename bugs
  + take into account that charset name "utf-8" resolves to
    "utf-8-strict" in recent Perl versions
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec  9 2005 mfabian@suse.de
- Bugzilla #135497: fixed by updating to 1.09.
* Wed Aug 25 2004 mfabian@suse.de
- update to 1.08.
* Fri Mar 26 2004 mfabian@suse.de
- add patch from author Bjoern Jacke:
  do not complain about wrong from_enc if to_enc is utf8 and
  files are, too. Thanks to Kuang-che Wu.
* Thu Jan 15 2004 mfabian@suse.de
- don't build as root.
- update to 1.07.
  New since 1.05:
  * add option to undo ugly http- and ftp-like escape sequences
  * add option to upper/lowercase virtually any charset
  * for upper/lower conversion add a "dotless i" option for
    Lithuanian, Turkish and Azeri
  * check for characters not allowed in POSIX filesystems
    (just in case someone wants to try to convert to UTF-16)
  * rewrote checkenc(), no more false alarms now with "encodings"
    like MIME-Q, which can look quite different.
* Thu Aug 14 2003 mfabian@suse.de
- small update from author:
  * add file length check
* Fri Jul 25 2003 mfabian@suse.de
- update to 1.05.
  From the Changes file:
  * --qfrom/to also mask cntrl characters now
  * symlink printout splitted to get correct output
  * missing $arg in symlink fixed (bug introduced in 1.02)
  * add NFS4 issues to documentation
  * add test suite
* Wed Jul 16 2003 mfabian@suse.de
- update to 1.04.
  From the Changes file:
  * add --exec option to allow arbitrary operations
  * add --lowmem option to keep memory footprint low when millions
    of files are being converted. However this will deactivate
    symlink target checks.
  * add Samba issues to documentation
  * suppress normalization error messages in cases of invalid
    UTF-8 in checkenc()
* Mon Jun 30 2003 mfabian@suse.de
- update to 1.02.
  From the Changes file:
  * make default behaviour to not work recursively so we can
    convert a single directory, use -r to get the old (recursive)
    mode
  * work around find() oddity, which doesn't process directories
    from @ARGV
  * die on unknown option
  * check if files exist and die otherwise
* Mon May 12 2003 mfabian@suse.de
- update to 1.01
- remove patch which requires Encode::HanExtra and Encode::JIS2K
  because these two packages use "enc2xs -C" in %%post and %%postun
  now which makes on demand loading of these encodings possible
  without a "require" in convmv.
* Fri May  9 2003 mfabian@suse.de
- add patch to require Encode::HanExtra and Encode::JIS2K
  if available
* Fri May  9 2003 mfabian@suse.de
- new package: convmv 1.0.
